@@ -42,7 +42,7 @@ try:
     from googleapiclient import discovery
     from googleapiclient import http
 except ImportError:
-    logger.warning("Loading GCS module without the python packages googleapiclient & oauth2client. \
+    logger.warning("Loading GCS module without the python packages googleapiclient & google-auth. \
         This will crash at runtime if GCS functionality is used.")
 else:
     # Retry transport and file IO errors.
@@ -89,9 +89,9 @@ class GCSClient(luigi.target.FileSystem):
 
        There are several ways to use this class. By default it will use the app
        default credentials, as described at https://developers.google.com/identity/protocols/application-default-credentials .
-       Alternatively, you may pass an oauth2client credentials object. e.g. to use a service account::
+       Alternatively, you may pass an google-auth credentials object. e.g. to use a service account::
 
-         credentials = oauth2client.client.SignedJwtAssertionCredentials(
+         credentials = google.auth.jwt.Credentials.from_service_account_info(
              '012345678912-ThisIsARandomServiceAccountEmail@developer.gserviceaccount.com',
              'These are the contents of the p12 file that came with the service account',
              scope='https://www.googleapis.com/auth/devstorage.read_write')
@@ -115,7 +115,7 @@ class GCSClient(luigi.target.FileSystem):
         if descriptor:
             self.client = discovery.build_from_document(descriptor, **authenticate_kwargs)
         else:
-            self.client = discovery.build('storage', 'v1', **authenticate_kwargs)
+            self.client = discovery.build('storage', 'v1', cache_discovery=False, **authenticate_kwargs)
 
     def _path_to_bucket_and_key(self, path):
         (scheme, netloc, path, _, _) = urlsplit(path)
@@ -245,7 +245,7 @@ class GCSClient(luigi.target.FileSystem):
         resumable = os.path.getsize(filename) > 0
 
         mimetype = mimetype or mimetypes.guess_type(dest_path)[0] or DEFAULT_MIMETYPE
-        media = http.MediaFileUpload(filename, mimetype, chunksize=chunksize, resumable=resumable)
+        media = http.MediaFileUpload(filename, mimetype=mimetype, chunksize=chunksize, resumable=resumable)
 
         self._do_put(media, dest_path)
 
